pub struct CredentialIdentity { /* private fields */ }Expand description
Validated identity for a stored provider credential.
Provider names are normalized to lowercase and environment-variable names are normalized to uppercase. Keeping both dimensions in a value object prevents a credential for one provider profile from being reused for another profile that happens to share the provider name.
Implementations
Sourceimpl CredentialIdentity
impl CredentialIdentity