pub fn load_oauth_token() -> Result<Option<OpenRouterToken>>Expand description
Load an OAuth token from storage using the default mode.
This function checks the selected secure backend and migrates the legacy encrypted file format when necessary.
pub fn load_oauth_token() -> Result<Option<OpenRouterToken>>Load an OAuth token from storage using the default mode.
This function checks the selected secure backend and migrates the legacy encrypted file format when necessary.