pub fn save_oauth_token(token: &OpenRouterToken) -> Result<()>Expand description
Save an OAuth token to encrypted storage using the default mode.
Uses the configured default credential storage mode.
pub fn save_oauth_token(token: &OpenRouterToken) -> Result<()>Save an OAuth token to encrypted storage using the default mode.
Uses the configured default credential storage mode.